Clazz.declarePackage("J.api");
Clazz.declareInterface(J.api, "GenericMenuInterface");
;//5.0.1-v7 Sat Jan 10 11:40:46 CST 2026
